@@ -11,6 +11,7 @@ from orangewidget.widget import Input, Output
 from oasys2.widget.widget import OWAction
 from oasys2.widget import gui as oasysgui
 from oasys2.widget.util.widget_util import EmittingStream
+from oasys2.widget.gui import Styles
 
 from syned.widget.widget_decorator import WidgetDecorator
 from syned.beamline.element_coordinates import ElementCoordinates
@@ -62,13 +63,13 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
         self.runaction.triggered.connect(self.run_shadow4)
         self.addAction(self.runaction)
 
-        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal")
+        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal", width=self.CONTROL_AREA_WIDTH-5)
 
         button = gui.button(button_box, self, "Run Shadow4/Trace", callback=self.run_shadow4)
-        button.setStyleSheet("color: darkblue; font-weight: bold; height: 45px;")
+        button.setStyleSheet(Styles.button_blue)
 
         button = gui.button(button_box, self, "Reset Fields", callback=self.call_reset_settings)
-        button.setStyleSheet("color: darkred; font-weight: bold; font-style: italic; height: 45px; width: 150px;")
+        button.setStyleSheet(Styles.button_red)
 
         #
         # tabs
@@ -280,10 +281,20 @@ class OWOpticalElement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
         pass
 
     def run_shadow4(self, scanning_data: ShadowData.ScanningData = None):
+        '''
+
+        :param scanning_data: these data come from a direct loop attached to this oe, the method managing the trigger is sending them.
+                              It is not None with a scanning variable or scanning file looper attached. Nested loops are not allowed, so if the
+                              input_data attribute contains scanning_data (from a thermal loop, for example), they will be used and the parameter is ignored.
+                              Nevertheless, in such a case, the scanning_data parameter, should be None.
+        '''
+
+
         if self.input_data is None:
             self.prompt_exception(ValueError("No input beam"))
             return
-        if not scanning_data: scanning_data = None
+        if not scanning_data: scanning_data = None # For some not yet understood problem, the variable is False by default instead of None.
+        if not self.input_data.scanning_data is None: scanning_data = self.input_data.scanning_data # from a loop starting elsewhere
 
         try:
             set_verbose()
