@@ -7,6 +7,7 @@ from orangewidget.widget import Input, Output
 from oasys2.widget import gui as oasysgui
 from oasys2.widget.widget import OWAction
 from oasys2.widget.util.widget_util import EmittingStream
+from oasys2.widget.gui import Styles
 from oasys2.canvas.util.canvas_util import add_widget_parameters_to_module
 from oasys2.widget.util.widget_objects import TriggerIn
 
@@ -61,13 +62,13 @@ class OWBeamMovement(GenericElement, WidgetDecorator, TriggerToolsDecorator):
         self.runaction.triggered.connect(self.run_shadow4)
         self.addAction(self.runaction)
 
-        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal")
+        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal", width=self.CONTROL_AREA_WIDTH-5)
 
         button = gui.button(button_box, self, "Run Shadow4/Trace", callback=self.run_shadow4)
-        button.setStyleSheet("color: darkblue; font-weight: bold; height: 45px;")
+        button.setStyleSheet(Styles.button_blue)
 
         button = gui.button(button_box, self, "Reset Fields", callback=self.call_reset_settings)
-        button.setStyleSheet("color: darkred; font-weight: bold; font-style: italic; height: 45px; width: 150px;")
+        button.setStyleSheet(Styles.button_red)
 
         #
         # tabs
