@@ -61,7 +61,7 @@ class OWUndulator(OWSynchrotronSource):
     def __init__(self):
         super().__init__(show_energy_spread=True)
 
-        tab_undulator = oasysgui.createTabPage(self.tabs_control_area, "Undulator Setting")
+        tab_undulator = oasysgui.createTabPage(self.tabs_control_area, "Undulator")
 
         # undulator parameters box
         left_box_3 = oasysgui.widgetBox(tab_undulator, "Undulator Parameters", addSpace=False, orientation="vertical")
@@ -109,7 +109,7 @@ class OWUndulator(OWSynchrotronSource):
         #
         # advanced settings
         #
-        tab_advanced = oasysgui.createTabPage(self.tabs_control_area, "Advanced Setting")
+        tab_advanced = oasysgui.createTabPage(self.tabs_control_area, "Advanced")
 
         # arrays
         left_box_11 = oasysgui.widgetBox(tab_advanced, "Array dimensions", addSpace=False, orientation="vertical")
