@@ -74,7 +74,7 @@ class Histogram(AutomaticElement):
     def __init__(self):
         super().__init__()
 
-        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal")
+        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal", width=self.CONTROL_AREA_WIDTH-5)
 
         gui.button(button_box, self, "Refresh", callback=self.plot_results, height=45)
         gui.button(button_box, self, "Save Current Plot", callback=self.save_results, height=45)
