@@ -91,7 +91,7 @@ class PlotScatter(AutomaticElement):
     def __init__(self):
         super().__init__()
 
-        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal")
+        button_box = oasysgui.widgetBox(self.controlArea, "", addSpace=False, orientation="horizontal", width=self.CONTROL_AREA_WIDTH-5)
 
         gui.button(button_box, self, "Refresh", callback=self.plot_results, height=45)
 
